@@ -5,8 +5,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef KONTACT_JOURNALPLUGIN_H
-#define KONTACT_JOURNALPLUGIN_H
+#pragma once
 
 #include <KontactInterface/Plugin>
 
@@ -47,4 +46,3 @@ private:
     KontactInterface::UniqueAppWatcher *mUniqueAppWatcher = nullptr;
 };
 
-#endif
