@@ -40,13 +40,16 @@ KOWhatsNextView::KOWhatsNextView(QWidget *parent)
 
     connect(mView, &EventViews::EventView::dissociateOccurrencesSignal, this, &KOrg::BaseView::dissociateOccurrencesSignal);
 
-    connect(mView, SIGNAL(newEventSignal()), SIGNAL(newEventSignal()));
+    connect(mView, qOverload<>(&EventViews::WhatsNextView::newEventSignal), this, qOverload<>(&KOWhatsNextView::newEventSignal));
 
-    connect(mView, SIGNAL(newEventSignal(QDate)), SIGNAL(newEventSignal(QDate)));
+    connect(mView, qOverload<const QDate &>(&EventViews::WhatsNextView::newEventSignal),
+            this, qOverload<const QDate &>(&KOWhatsNextView::newEventSignal));
 
-    connect(mView, SIGNAL(newEventSignal(QDateTime)), SIGNAL(newEventSignal(QDateTime)));
+    connect(mView, qOverload<const QDateTime &>(&EventViews::WhatsNextView::newEventSignal),
+            this, qOverload<const QDateTime &>(&KOWhatsNextView::newEventSignal));
 
-    connect(mView, SIGNAL(newEventSignal(QDateTime, QDateTime)), SIGNAL(newEventSignal(QDateTime, QDateTime)));
+    connect(mView, qOverload<const QDateTime &, const QDateTime &>(&EventViews::WhatsNextView::newEventSignal),
+            this, qOverload<const QDateTime &, const QDateTime &>(&KOWhatsNextView::newEventSignal));
 
     connect(mView, &EventViews::EventView::newTodoSignal, this, &KOrg::BaseView::newTodoSignal);
 
